DigitsLarge

Trait DigitsLarge 

pub trait DigitsLarge {
    // Required method
    fn digits_large(&mut self, x: i32, y: i32, text: &str) -> i32;
}
Write on a surface using the large digit typeface

Required Methods

fn digits_large(&mut self, x: i32, y: i32, text: &str) -> i32

Write the text with the baseline starting at the given position. Returns the width of the text in pixels.

Implementors