DigitsMedium

Trait DigitsMedium 

pub trait DigitsMedium {
    // Required method
    fn digits_medium(&mut self, x: i32, y: i32, text: &str) -> i32;
}
Write on a surface using the medium digit typeface

Required Methods

fn digits_medium(&mut self, x: i32, y: i32, text: &str) -> i32

Write the text with the baseline starting at the given position. Returns the width of the text in pixels.

Implementors