Platform independent code for drawing to monochrome surfaces
Structs
- Measure
- This struct implements the Surface trait and can be used to measure the width of text without drawing anything
- Rotate
- Rotate a surface
Traits
- Awakening
- Write on a surface using the Awakening typeface
- Digits
Large - Write on a surface using the large digit typeface
- Digits
Medium - Write on a surface using the medium digit typeface
- Premium
- Write on a surface using the Premium typeface
- Surface
- A drawable surface